motifCountMatrix: Motif count matrix.

Description Usage Arguments Value

View source: R/motifCountMatrix.R

Description

The function can be used to retrieve a subset of the motif count matrix stored in a promoter.DB object, for a set of genes given as input. The promoter.DB objets are as generated by the functions makePromoterDBfromFimo or makePromoterDBfromRE.

Usage

1
motifCountMatrix(Genes, promoterDB = "promoter.DB", strand = "both")

Arguments

Genes

A list of the genes of interest.

promoterDB

Promoter.DB object,

strand

A character string that can take value: "plus", "minus" or "both".

Value

A promoter.DB object


jsalojar/TFbindR documentation built on Dec. 9, 2019, 12:16 a.m.