Description Usage Arguments Value
View source: R/motifCountMatrix.R
The function can be used to retrieve a subset of the motif count matrix stored in a promoter.DB object, for a set of genes given as input. The promoter.DB objets are as generated by the functions makePromoterDBfromFimo or makePromoterDBfromRE.
1 | motifCountMatrix(Genes, promoterDB = "promoter.DB", strand = "both")
|
Genes |
A list of the genes of interest. |
promoterDB |
Promoter.DB object, |
strand |
A character string that can take value: "plus", "minus" or "both". |
A promoter.DB object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.